@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.6.1-1
+# Application Name - Health Check V0.7.0-0
 #Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -25,59 +25,239 @@
 # import PyQt4 & sys
 print "** Start Imports **"
 print "** Importing qtcore & gui **"
-from PyQt4 import QtCore, QtGui
-print "** Importing ui.touchstub - accuracy tool **"
-from ui.touchstub import aMainWindow
-print "** Importing sys **"
-import sys
-# To allow os.popen ('<<Terminal command>>').read() commands
-print "** Importing os **"
-import os
-# To allow os.popen() to work
-print "** Importing subprocess **"
-import subprocess
-print "** Importing dbus.glib **"
-import dbus.glib
-# GPS ones
-print "** Importing Start location**"
-import location
+try:
+    from PyQt4 import QtCore, QtGui
+except:
+    print "Unexpected error: Importing QtCore and QtGui"
+    raise
 
+print "** Importing ui.touchstub - accuracy tool **"
+try:
+    from ui.touchstub import aMainWindow
+except:
+    print "Unexpected error: Importing ui.touchstub (Accuracy test)"
+    raise
+
+print "** Importing sys **"
+try:
+    import sys
+    import commands
+except:
+    print "Unexpected error: Importing sys"
+    raise
+
+print "** Importing os **"
+try:
+    import os
+    import os.path
+except:
+    print "Unexpected error: Importing os"
+    raise
+
+print "** Importing subprocess **"
+try:
+    import subprocess
+except:
+    print "Unexpected error: Importing ui.touchstub (Accuracy test)"
+    raise
+
+print "** Importing dbus.glib **"
+try:
+    import dbus.glib
+except:
+    print "Unexpected error: Importing dbus.glib"
+    raise
+
+print "** Importing Start location**"
+try:
+    import location
+except:
+    print "Unexpected error: Importing location"
+    raise
+
+# GPS ones
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
+
 print "** Importing Cellinfo **"
-import gn_cellinfo
+try:
+    import gn_cellinfo
+except:
+    print "Unexpected error: Importing gn_cellinfo"
+    raise
+
 print "** Importing Hildon **"
-import hildon
+try:
+    import hildon
+except:
+    print "Unexpected error: Importing hildon"
+    raise
 
 #for phone orientation call
 #import dbus
 #import dbus.glib
 print "** Importing Threading **"
-from threading import Thread
+try:
+    from threading import Thread
+except:
+    print "Unexpected error: Importing Thread (from threading)"
+    raise
+
 print "** Importing Time **"
-import time
+try:
+    import time
+except:
+    print "Unexpected error: Importing time"
+    raise
+
 print "** Importing GTK **"
-import gtk
+try:
+    import gtk
+except:
+    print "Unexpected error: Importing gtk"
+    raise
+
 print "** Initialize Threads **"
-gtk.gdk.threads_init()
+try:
+    gtk.gdk.threads_init()
+except:
+    print "Unexpected error: Initializing Threads gtk.gdk.threads_init()"
+    raise
+
 print "** Importing Gobject **"
-import gobject
+try:
+    import gobject
+except:
+    print "Unexpected error: Importing gobject"
+    raise
+
+
 print "** Finish Imports **"
 
 
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
+
+# Location of the DPKG files
+dpkg_dir = '/var/lib/dpkg'
+
+# Global variables
 print "** Seting global variables **"
 var_g_GPS = "No GPS lock"
 bname = "Move R"
+name_lookup = {}
+rootfs_id = ''
 
 
+class imagea(QtGui.QMainWindow):
+
+    def __init__(self, *args):
+        apply(QtGui.QMainWindow.__init__, (self,) + args)
+        print "** Starting Hellowindow Class **"
+        #self.Qt::WA_Maemo5StackedWindow 
+        print "** Set basic color on rectangle **"
+        self.color = QtGui.QColor(0, 0, 0) 
+        print "** Setting window details and loading form**"
+        self.setGeometry(0, 0, 800, 480)
+        self.setWindowTitle('Front Camera Image')
+
+        self.lbl_CameraShow = QtGui.QLabel(self)
+        self.lbl_CameraShow.setGeometry(QtCore.QRect(160, 10, 455, 341))
+        self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
+        self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
+        self.lbl_CameraShow.setLineWidth(2)
+        self.lbl_CameraShow.setMidLineWidth(1)
+        self.lbl_CameraShow.setScaledContents(True)
+        self.lbl_CameraShow.setObjectName("lbl_CameraShow")
+
+        
+        # Setup and draw the button
+        self.pushButton_cam = QtGui.QPushButton(self)
+        self.pushButton_cam.setGeometry(QtCore.QRect(10, 380, 331, 71))
+        self.pushButton_cam.setObjectName("pushButton_cam")
+        self.pushButton_cam.setText("Front camera")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
+
+        # Setup and draw the button
+        self.pushButton_cam2 = QtGui.QPushButton(self)
+        self.pushButton_cam2.setGeometry(QtCore.QRect(350, 380, 331, 71))
+        self.pushButton_cam2.setObjectName("pushButton_cam2")
+        self.pushButton_cam2.setText("Back camera")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
+
+        self.exitb = QtGui.QPushButton('X', self)
+        self.exitb.setGeometry(QtCore.QRect(690, 380, 101, 71))
+        self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
+
+
+    def updateTab3(self):
+        print " ** Starting update3**"
+        self.pushButton_cam.setEnabled(False)
+        self.pushButton_cam.setText("....")
+        self.updateImage()
+        self.pushButton_cam.setText("Front camera")
+        self.pushButton_cam.setEnabled(True)
+
+    def updateTab3a(self):
+        print " ** Starting update3a**"
+        self.pushButton_cam2.setEnabled(False)
+        self.pushButton_cam2.setText("....")
+        self.updateImage2()
+        self.pushButton_cam2.setText("Back Camera")
+        self.pushButton_cam2.setEnabled(True)
+    # Funtion - update the front camera image
+    def updateImage(self):
+        print "** Starting front camera function **"
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
+        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+        b = None
+        # X-term - grab 10 buffered front camera images, and throw them into an image file.
+        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+        b = os.popen('gst-launch v4l2camsrc device=/dev/video1 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+        b.close ()
+        # Declare and set the image file name
+        image_file = "/home/user/MyDocs/fcamtest.jpg"
+        image = QtGui.QPixmap(image_file)
+        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+        self.lbl_CameraShow.setPixmap(image)
+        print " ** Finished front camera function **"
+
+    def updateImage2(self):
+        print " ** Starting back camera function **"
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
+        
+        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+        b = None
+        # X-term - grab 10 buffered front camera images, and throw them into an image file.
+        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+        b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+        b.close ()
+        # Declare and set the image file name
+        image_file = "/home/user/MyDocs/fcamtest.jpg"
+        image = QtGui.QPixmap(image_file)
+        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+        self.lbl_CameraShow.setPixmap(image)
+        print " ** Finished Back camera function **"
+
+
+
+        
+
 class HelloWindow(QtGui.QMainWindow):
 
     def __init__(self, *args):
         apply(QtGui.QMainWindow.__init__, (self,) + args)
         print "** Starting Hellowindow Class **"
+        #checkpkgs()
         global bname
         #self.Qt::WA_Maemo5StackedWindow 
         print "** Set basic color on rectangle **"
@@ -115,7 +295,7 @@ class HelloWindow(QtGui.QMainWindow):
         self.exitb.move(10, 210)
         self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.exitB)
         print "** Completed Hellowindow Class load **"
-        #QtGui.QApplication.setStyle(QtGui.QStyleFactory.create('cleanlooks'))
+ 
 
     def moveB(self):
         print "** moving buttons **"
@@ -190,6 +370,11 @@ class Ui_MainWindow(object):
         MainWindow.setFont(font)
 
 
+
+
+        
+
+
         # Not sure - QTDesigner did this bit - assuming it's loading up the form and a widget
         self.centralwidget = QtGui.QWidget(MainWindow)
         self.centralwidget.setObjectName("centralwidget")
@@ -276,30 +461,7 @@ class Ui_MainWindow(object):
         # Set up the Front Camera label
 
         # This label is used to show the Front Camera widget
-        self.lbl_CameraShow = QtGui.QLabel(self.tab_3)
-        self.lbl_CameraShow.setGeometry(QtCore.QRect(0, 10, 455, 341))
-        self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
-        self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
-        self.lbl_CameraShow.setLineWidth(2)
-        self.lbl_CameraShow.setMidLineWidth(1)
-        self.lbl_CameraShow.setScaledContents(True)
-        self.lbl_CameraShow.setObjectName("lbl_CameraShow")
         
-        # Setup and draw the button
-        self.pushButton_cam = QtGui.QPushButton(self.tab_3)
-        self.pushButton_cam.setGeometry(QtCore.QRect(450, 250, 340, 51))
-        self.pushButton_cam.setObjectName("pushButton_cam")
-        self.pushButton_cam.setText("Front camera")
-        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
-
-        # Setup and draw the button
-        self.pushButton_cam2 = QtGui.QPushButton(self.tab_3)
-        self.pushButton_cam2.setGeometry(QtCore.QRect(450, 310, 340, 51))
-        self.pushButton_cam2.setObjectName("pushButton_cam2")
-        self.pushButton_cam2.setText("Back camera")
-        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
 
         # Show the tab and draw contents
         self.tabWidget.addTab(self.tab_3, "")
@@ -308,20 +470,26 @@ class Ui_MainWindow(object):
         self.tab_4 = QtGui.QWidget()
         self.tab_4.setObjectName("tab_4")
 
-        # Setup and draw the button
-        self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
-        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 280, 391, 51))
-        self.pushButton_reboot.setObjectName("pushButton_reboot")
-        self.pushButton_reboot.setText("System Reboot")
+        self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
+        self.pushButton_snd1.setGeometry(QtCore.QRect(10, 10, 391, 51))
+        self.pushButton_snd1.setObjectName("pushButton_snd1")
+        self.pushButton_snd1.setText("Test Sound")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
+        QtCore.QObject.connect(self.pushButton_snd1, QtCore.SIGNAL('clicked()'), self.updatesound)
 
-        self.color_test = QtGui.QPushButton(self.tab_4)
-        self.color_test.setGeometry(QtCore.QRect(400, 190, 391, 51))
-        self.color_test.setObjectName("color_test")
-        self.color_test.setText("Dead Pixel Test")
+        self.pushButton_led = QtGui.QPushButton(self.tab_4)
+        self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
+        self.pushButton_led.setObjectName("pushButton_led")
+        self.pushButton_led.setText("Test LEDs")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.color_test, QtCore.SIGNAL('clicked()'), self.show_new_window)
+        QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
+
+        self.pushButton_von = QtGui.QPushButton(self.tab_4)
+        self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
+        self.pushButton_von.setObjectName("pushButton_von")
+        self.pushButton_von.setText("Test Vibrate")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
         self.xyscreen = QtGui.QPushButton(self.tab_4)
         self.xyscreen.setGeometry(QtCore.QRect(10, 190, 391, 51))
@@ -330,53 +498,22 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.xyscreen, QtCore.SIGNAL('clicked()'), self.show_new_window2)
 
-        
-        
-
-        self.vibra_led = QtGui.QComboBox(self.tab_4)
-        self.vibra_led.setGeometry(QtCore.QRect(400, 130, 391, 51))
-        self.vibra_led.setObjectName("vibra_led")
-        self.vibra_led.addItem("PatternIncomingCall")
-        self.vibra_led.addItem("PatternIncomingMessage")
-        #self.vibra_led.addItem("PatternPowerKeyPress")
-        #self.vibra_led.addItem("PatternTouchScreen")
-        self.vibra_led.addItem("PatternChatAndEmail")
-        
-        
-        self.pushButton_von = QtGui.QPushButton(self.tab_4)
-        self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
-        self.pushButton_von.setObjectName("pushButton_von")
-        self.pushButton_von.setText("Test Vibrate")
+        # Setup and draw the button
+        self.pushButton_cama = QtGui.QPushButton(self.tab_4)
+        self.pushButton_cama.setGeometry(QtCore.QRect(10, 250, 391, 51))
+        self.pushButton_cama.setObjectName("pushButton_cama")
+        self.pushButton_cama.setText("Camera Tests")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
-
-        self.combo_led = QtGui.QComboBox(self.tab_4)
-        self.combo_led.setGeometry(QtCore.QRect(400, 70, 391, 51))
-        self.combo_led.setObjectName("combo_led")
-        self.combo_led.addItem("PatternError")
-        #self.combo_led.addItem("PatternDeviceOn")
-        #self.combo_led.addItem("PatternDeviceSoftOff")
-        self.combo_led.addItem("PatternPowerOn")
-        self.combo_led.addItem("PatternPowerOff")
-        self.combo_led.addItem("PatternCommunicationCall")
-        #self.combo_led.addItem("PatternCommunicationIM")
-        self.combo_led.addItem("PatternCommunicationSMS")
-        #self.combo_led.addItem("PatternCommunicationEmail")
-        #self.combo_led.addItem("PatternCommonNotification")
-        #self.combo_led.addItem("PatternBatteryCharging")
-        #self.combo_led.addItem("PatternBatteryFull")
-
+        QtCore.QObject.connect(self.pushButton_cama, QtCore.SIGNAL('clicked()'), self.updateimage)
         
+        # Setup and draw the button
+        self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 310, 391, 51))
+        self.pushButton_reboot.setObjectName("pushButton_reboot")
+        self.pushButton_reboot.setText("System Reboot")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        #QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
-        
+        QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
-        self.pushButton_led = QtGui.QPushButton(self.tab_4)
-        self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
-        self.pushButton_led.setObjectName("pushButton_led")
-        self.pushButton_led.setText("Test LEDs")
-        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
 
         self.sound_lst = QtGui.QComboBox(self.tab_4)
         self.sound_lst.setGeometry(QtCore.QRect(400, 10, 391, 51))
@@ -387,13 +524,55 @@ class Ui_MainWindow(object):
                 self.sound_lst.addItem(f)
         #self.sound_lst.addItem("PatternIncomingCall")
 
+        self.combo_led = QtGui.QComboBox(self.tab_4)
+        self.combo_led.setGeometry(QtCore.QRect(400, 70, 391, 51))
+        self.combo_led.setObjectName("combo_led")
+        self.combo_led.addItem("PatternError")
+        self.combo_led.addItem("PatternPowerOn")
+        self.combo_led.addItem("PatternPowerOff")
+        self.combo_led.addItem("PatternCommunicationCall")
+        self.combo_led.addItem("PatternCommunicationSMS")
 
-        self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
-        self.pushButton_snd1.setGeometry(QtCore.QRect(10, 10, 391, 51))
-        self.pushButton_snd1.setObjectName("pushButton_snd1")
-        self.pushButton_snd1.setText("Test Sound")
+        self.vibra_led = QtGui.QComboBox(self.tab_4)
+        self.vibra_led.setGeometry(QtCore.QRect(400, 130, 391, 51))
+        self.vibra_led.setObjectName("vibra_led")
+        self.vibra_led.addItem("PatternIncomingCall")
+        self.vibra_led.addItem("PatternIncomingMessage")
+        #self.vibra_led.addItem("PatternPowerKeyPress")
+        #self.vibra_led.addItem("PatternTouchScreen")
+        self.vibra_led.addItem("PatternChatAndEmail")
+
+        self.color_test = QtGui.QPushButton(self.tab_4)
+        self.color_test.setGeometry(QtCore.QRect(400, 190, 391, 51))
+        self.color_test.setObjectName("color_test")
+        self.color_test.setText("Dead Pixel Test")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-        QtCore.QObject.connect(self.pushButton_snd1, QtCore.SIGNAL('clicked()'), self.updatesound)
+        QtCore.QObject.connect(self.color_test, QtCore.SIGNAL('clicked()'), self.show_new_window)
+
+        
+
+        
+        
+
+        
+        
+        
+        
+
+        
+        
+
+        
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        #QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
+        
+
+        
+
+        
+
+
+        
     
         self.tabWidget.addTab(self.tab_4, "")
 
@@ -406,7 +585,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.6.1-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test) & Lcuk(Everything!)\n And to all the testers.")
+        self.textBrowser.setText (" Health Check V0.7.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -437,16 +616,18 @@ class Ui_MainWindow(object):
 
 
 
-    def show_new_window(self):
-                   
+    def show_new_window(self):           
         win.show()
         win.showFullScreen()
-        #appt.connect(appt, SIGNAL("lastWindowClosed()"),appt, SLOT("quit()"))
-        #appt.exec_loop()
 
     def show_new_window2(self):  
         aui.show()
         aui.showFullScreen()
+        
+    def updateimage(self):  
+        imagewin.show()
+        imagewin.showFullScreen()
+
 
 
         
@@ -539,45 +720,7 @@ class Ui_MainWindow(object):
         b = os.popen(bb)
         b.close ()
               
-# Funtion - update the front camera image
-    def updateImage(self):
-        print "** Starting front camera function **"
-        bus = dbus.SessionBus()
-        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, 'general_refresh', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
-        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-        b = None
-        # X-term - grab 10 buffered front camera images, and throw them into an image file.
-        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-        b = os.popen('gst-launch v4l2camsrc device=/dev/video1 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
-        b.close ()
-        # Declare and set the image file name
-        image_file = "/home/user/MyDocs/fcamtest.jpg"
-        image = QtGui.QPixmap(image_file)
-        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-        self.lbl_CameraShow.setPixmap(image)
-        print " ** Finished front camera function **"
 
-    def updateImage2(self):
-        print " ** Starting back camera function **"
-        bus = dbus.SessionBus()
-        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
-        
-        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-        b = None
-        # X-term - grab 10 buffered front camera images, and throw them into an image file.
-        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-        b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
-        b.close ()
-        # Declare and set the image file name
-        image_file = "/home/user/MyDocs/fcamtest.jpg"
-        image = QtGui.QPixmap(image_file)
-        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-        self.lbl_CameraShow.setPixmap(image)
-        print " ** Finished Back camera function **"
   
 # Funtion - update Firmware version label
     def updateMaemoV(self):
@@ -601,7 +744,7 @@ class Ui_MainWindow(object):
         elif g.strip() == "2009.51-1.203.2":
             self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.203.1":
-            self.listWidget.addItem("FirmwareVersion \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.205.1":
             self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
         elif g.strip() == "2009.51-1.205.2":
@@ -890,28 +1033,14 @@ class Ui_MainWindow(object):
         interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
         print " ** Finished Tab 2 update **"
 
-    def updateTab3(self):
-        print " ** Starting update3**"
-        self.pushButton_cam.setEnabled(False)
-        self.pushButton_cam.setText("....")
-        self.updateImage()
-        self.pushButton_cam.setText("Front camera")
-        self.pushButton_cam.setEnabled(True)
-
-    def updateTab3a(self):
-        print " ** Starting update3a**"
-        self.pushButton_cam2.setEnabled(False)
-        self.pushButton_cam2.setText("....")
-        self.updateImage2()
-        self.pushButton_cam2.setText("Back Camera")
-        self.pushButton_cam2.setEnabled(True)
+  
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.1-1", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.7.0-0", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
-        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
         
@@ -1034,6 +1163,189 @@ def start_location(data):
     data.start()
     return False
 
+def read_names():
+    global dpkg_dir
+    global name_lookup
+    pkg = ''
+
+    # Read though the DPKG status file
+    pkg_stat = open(dpkg_dir + '/status', 'r')
+
+    for line in pkg_stat:
+        line = line.rstrip()
+
+        # Extract the package name and display name
+        if line[0:8] == 'Package:':
+            pkg = line[9:]
+        elif line[0:19] == 'Maemo-Display-Name:':
+            # Only store the display name if it's different
+            full_name = line[20:]
+
+            if pkg != full_name:
+                name_lookup[pkg] = full_name
+
+    pkg_stat.close()
+
+# Lookup the full display name for a package
+def get_name(pkg):
+    global name_lookup
+
+    # Check whether a full display name exists for this package
+    if name_lookup.has_key(pkg):
+        return name_lookup[pkg]
+
+    return
+
+# Return the filesystem ID for the specified file/directory
+def get_fsid(file):
+    return os.stat(file).st_dev
+
+# Check whether the specified file is on the rootfs or not
+def is_rootfs(file):
+    global rootfs_id
+    global rootfs_pkg
+
+    # Store the rootfs ID if it hasn't yet been set
+    if rootfs_id == '':
+        rootfs_id = get_fsid('/')
+
+    # Check whether the filesystem ID matches that of the rootfs
+    if get_fsid(file) == rootfs_id:
+        return 1
+
+    return 0
+
+# Find the on-disk usage of a file
+def disk_usage(file, seen):
+    # Run stat on the file
+    stat = os.stat(file)
+
+    inode = stat.st_ino
+    if seen.has_key(inode):
+        return
+
+    seen[inode] = 1
+
+    blksize = stat.st_blksize       # Block size for the disk
+    chunknum = stat.st_blocks       # Number of 512b blocks used by file
+    blk_mult = blksize / 512        # How many 512b chunks are in one block
+
+    # Work out how many blocks the file is actually using
+    blk_count = (chunknum + blk_mult - 1) / blk_mult
+
+    # Return the size in kb
+    return blk_count * blksize / 1024
+
+# Lookup the sizes for a given package
+def get_size(pkg, list = 0):
+    global dpkg_dir
+
+    # Open the packages .list file
+    try:
+        pkg_info = open(dpkg_dir + '/info/' + pkg + '.list', 'r')
+        dulist = {}
+        seen = {}
+
+        # Read through and store the paths for files on the rootfs
+        for file in pkg_info:
+            file = file.rstrip()
+
+            if not os.path.isfile(file):
+                continue
+            if os.path.islink(file):
+                continue
+            if not is_rootfs(file):
+                continue
+
+            # Lookup the disk usage of the file
+            size = disk_usage(file, seen)
+
+            if size is None:
+                continue
+            if size == 0:
+                continue
+
+            dulist[file] = size
+    except IOError:
+        return
+    finally:
+        pkg_info.close()
+
+    # Check whether there are any files on the rootfs
+    if len(dulist) == 0:
+        return
+
+    # Return either the total size or the list of individual file sizes
+    if list == 0:
+        return sum(dulist.values())
+    else:
+        return dulist
+
+# Get the total rootfs size for all non-l10n packages
+def checkpkgs():
+    # Store the display names for later lookup
+    read_names()
+
+    # Loop through all files in the DPKG info directory
+    for file in os.listdir(dpkg_dir + '/info'):
+        # Skip any that aren't .list files
+        if file[-5:] != '.list':
+            continue
+
+        # Skip the l10n packages
+        if file.find('l10n') > -1:
+            continue
+
+        # Extract the package name
+        pkg = file[0:len(file) - 5]
+
+        # Lookup the package rootfs size
+        size = get_size(pkg)
+
+        # Skip further processing if there's no rootfs usage
+        if size is None:
+            continue
+
+        # Lookup the package's display name
+        name = get_name(pkg)
+
+        # If there is one, append it in brackets
+        if not name is None:
+            pkg = pkg + ' (' + name + ')'
+
+        # Output the package size and name
+        print '%d\t%s' % (size, pkg)
+
+# List the rootfs files in the given package (and their sizes)
+def pkglist(pkg):
+    # Lookup the array of files and sizes
+    sizes = get_size(pkg, 1)
+
+    # Output the info
+    if not sizes is None:
+        for (file, size) in sizes.items():
+            print "%d\t%s" % (size, file)
+
+# Report the total rootfs usage for the given package
+def pkgsize(pkg):
+    # Lookup the rootfs usage
+    size = get_size(pkg)
+
+    # Report the rootfs usage (or 0 if there is none)
+    if size is None:
+        print '0\t%s' % pkg
+    else:
+        print '%d\t%s' % (size, pkg)
+
+# Use the first parameter as the command to run.
+#if sys.argv[1] == 'checkpkgs':
+    #checkpkgs()
+#elif sys.argv[1] == 'pkglist':
+    #pkglist(sys.argv[2])
+#elif sys.argv[1] == 'pkgsize':
+    #pkgsize(sys.argv[2])
+
+
 
 # Start the main program/function
 if __name__ == "__main__":
@@ -1041,7 +1353,7 @@ if __name__ == "__main__":
     print " ** Starting Main **"
     print " ** app = QtGui App** - Running app = QtGui.QApplication(sys.argv) **"
     app = QtGui.QApplication(sys.argv)
-
+    #QtGui.QApplication.setStyle(QtGui.QStyleFactory.create('windowsxp'))
     #app = QtGui.QApplication(sys.argv)
     print " ** Setting Main Window**"
     MainWindow = QtGui.QMainWindow()
@@ -1050,6 +1362,8 @@ if __name__ == "__main__":
     win = HelloWindow(MainWindow)
     print "** Setting tool window #2**"
     aui = aMainWindow(MainWindow)
+    print "** Setting Video window**"
+    imagewin = imagea(MainWindow)
     print " ** Declare the UI**"
     ui = Ui_MainWindow()
     print " ** Draw everything and start the main function**"
